@@ -1,7 +1,7 @@
 /*
 MySecureShell permit to add restriction to modified sftp-server
 when using MySecureShell as shell.
-Copyright (C) 2007 Sebastien Tardif
+Copyright (C) 2007-2014 MySecureShell Team
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -28,7 +28,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define	MYLOG_DEBUG		5
 #define	MYLOG_MAX		6
 
-void	mylog_open(const char *file);
+void	mylog_open(char *file, int useSyslog);
 void	mylog_close_and_free();
 void	mylog_close();
 void	mylog_reopen();
